# scbl-db

The ORM of the sample-tracking database used at the Single Cell Biology Laboratory at the [Jackson Laboratory](https://www.jax.org/). This ORM is currently incomplete - it only supports a subset of the platforms available at the Single Cell Biology Laboratory.
